@@ -57,7 +57,8 @@ recipe_list_string = [
          ]
 
 def _teststore():
-    return Store(config['server_store'][0], environ={'tiddlyweb.config': config})
+    return Store(config['server_store'][0], config['server_store'][1],
+            environ={'tiddlyweb.config': config})
 
 def reset_textstore():
     if os.path.exists('store'):
