@@ -196,6 +196,19 @@ def test_put_recipe():
     assert response['status'] == '204'
     assert response['location'] == 'http://our_test_domain:8001/recipes/other'
 
+def test_put_bad_recipe():
+    """
+    Get a recipe as json then put it back with a different name.
+    """
+    http = httplib2.Http()
+
+    response, content = http.request('http://our_test_domain:8001/recipes/other',
+            method='PUT', headers={'Content-Type': 'application/json'},
+            body='{ "recipe": null }')
+
+    assert response['status'] == '400'
+    assert 'malformed input' in content
+
 def test_put_recipe_change_description():
     """
     Get a recipe as json then put it back with a different name.
